//========================================================================================
//
//	File:				SLColor.h
//	Release Version:	$ ODF 1 $
//
//	Copyright:	(c) 1993 - 1996 by Apple Computer, Inc., all rights reserved.
//
//========================================================================================

#ifndef SLCOLOR_H
#define SLCOLOR_H

#ifndef SLGRDEF_H
#include "SLGrDef.h"
#endif

// Export or Import functions for CFM-68K [sfu]

#if defined(FW_ODFLIB_IMPORT)
#pragma import on
#elif defined(FW_ODFLIB)
#pragma export on
#endif

FW_EXTERN_C_BEGIN

//========================================================================================
// Type definitions
//========================================================================================

struct	FW_SColor
{
	unsigned long	fRGB;
};

#define FW_RGB(r, g, b)	(((unsigned long)(r)) | ((unsigned long)(g) << 8) | ((unsigned long)(b) << 16))

inline void FW_SetRGB(FW_SColor& color, short r, short g, short b)
{
	color.fRGB = FW_RGB(r, g, b);
}

inline unsigned char FW_RGB_R(FW_SColor color)
{
	return (unsigned char) (color.fRGB);
}

inline unsigned char FW_RGB_G(FW_SColor color)
{
	return (unsigned char) (color.fRGB >> 8);
}

inline unsigned char FW_RGB_B(FW_SColor color)
{
	return (unsigned char) (color.fRGB >> 16);
}

//========================================================================================
// Color utilities
//========================================================================================

FW_Boolean	operator==(const FW_SColor& color1, const FW_SColor& color2);
FW_Boolean	operator!=(const FW_SColor& color1, const FW_SColor& color2);

inline FW_Boolean	operator==(const FW_SColor& color1, const FW_SColor& color2)
{
	return color1.fRGB == color2.fRGB;
}

inline FW_Boolean	operator!=(const FW_SColor& color1, const FW_SColor& color2)
{
	return color1.fRGB != color2.fRGB;
}

//========================================================================================
// Color conversion functions
//========================================================================================

#ifdef FW_BUILD_WIN

FW_SColor		SL_API
FW_WinRGBQuadToColor(const RGBQUAD* rgbQuad);

FW_SColor		SL_API
FW_WinRGBTripleToColor(const RGBTRIPLE* rgbTriple);

void			SL_API
FW_WinColorToRGBQuad(FW_SColor rgb, RGBQUAD* rgbQuad);

void			SL_API
FW_WinColorRGBTriple(FW_SColor rgb, RGBTRIPLE* rgbTriple);

#endif

#ifdef FW_BUILD_MAC

FW_SColor		SL_API
FW_MacRGBToColor(const RGBColor* rgbColor);

void			SL_API
FW_MacColorToRGB(FW_SColor rgb, RGBColor* rgbColor);

#endif

FW_EXTERN_C_END

// For CFM-68K [sfu]

#if defined(FW_ODFLIB_IMPORT)
#pragma import off
#elif defined(FW_ODFLIB)
#pragma export off
#endif

#endif // SLCOLOR_H
