//========================================================================================
//
//	File:				FWPriRas.h
//	Release Version:	$ ODF 1 $
//
//	Copyright:	(c) 1993 - 1996 by Apple Computer, Inc., all rights reserved.
//
//========================================================================================

#ifndef SLRENDER_H
#define SLRENDER_H

#ifndef SLGRDEF_H
#include "SLGrDef.h"
#endif

#ifndef SLGCONST_K
#include "SLGConst.k"
#endif

#ifndef SLSHATTR_H
#include "SLShAttr.h"
#endif

#ifndef SLICON_H
#include "SLIcon.h"
#endif

#ifndef SLPOLY_H
#include "SLPoly.h"
#endif

#ifndef SLPICTUR_H
#include "SLPictur.h"
#endif

#ifndef SLBITMAP_H
#include "SLBitmap.h"
#endif

#ifndef SLSTRREP_H
#include "SLStrRep.h"
#endif

#ifndef SLCHARIT_H
#include "SLCharIt.h"
#endif

//========================================================================================
// Forward declarations
//========================================================================================

struct FW_SGraphicContext;

class ODShape;

//========================================================================================
// Rendering APIs
//========================================================================================

// Export or Import functions for CFM-68K [sfu]

#if defined(FW_ODFLIB_IMPORT)
#pragma import on
#elif defined(FW_ODFLIB)
#pragma export on
#endif

FW_EXTERN_C_BEGIN

void 		SL_API	FW_PrivRenderRect(Environment* ev,
						FW_SGraphicContext&	gc,
						const FW_SRect&		rect,
						FW_ERenderVerbs		renderVerb,
						FW_HInk				ink,
						FW_HStyle 			style);

void		SL_API	FW_PrivRenderOval(Environment* ev,
						FW_SGraphicContext&	gc,
						const FW_SRect&		rect,
						FW_ERenderVerbs		renderVerb,
						FW_HInk				ink,
						FW_HStyle			style);
							
void		SL_API	FW_PrivRenderRoundRect(Environment* ev,
						FW_SGraphicContext&	gc,
						const FW_SRect&		rect,
						const FW_SPoint&	ovalSize,
						FW_ERenderVerbs		renderVerb,
						FW_HInk				ink,
						FW_HStyle 			style);
							
void		SL_API	FW_PrivRenderArc(Environment* ev,
						FW_SGraphicContext&	gc,
						const FW_SRect& 	rect, 
						short 				startAngle,
						short 				arcAngle,
						FW_ERenderVerbs		renderVerb,
						FW_HInk				ink,
						FW_HStyle			style);

void		SL_API	FW_PrivRenderLine(Environment* ev,
						FW_SGraphicContext&	gc,
						const FW_SPoint&	start, 
						const FW_SPoint&	end,
						FW_ERenderVerbs		renderVerb,
						FW_HInk				ink,
						FW_HStyle			style);

void		SL_API	FW_PrivRenderRegion(Environment* ev,
						FW_SGraphicContext& gc,
						ODShape*			odShape,
						FW_ERenderVerbs		renderVerb,
						FW_HInk				ink,
						FW_HStyle			style);
											
void		SL_API	FW_PrivRenderPolygon(Environment* ev,
						FW_SGraphicContext& gc,
						FW_HPolygon			polygon,
						FW_ERenderVerbs 	renderVerb,
						FW_Boolean 			autoCloseFrame,
						FW_HInk 			ink,
						FW_HStyle 			style);
											
void		SL_API	FW_PrivRenderTextString(Environment* ev,
						FW_SGraphicContext&	gc,
						FW_HString			string,
						const FW_SPoint&	position,
						FW_TextAlignment	textAlignment,
						FW_ERenderVerbs		renderVerb,
						FW_HInk				ink,
						FW_HFont 			font);
								
void		SL_API	FW_PrivRenderTextReader(Environment* ev,
						FW_SGraphicContext&	gc,
						FW_HTextReader		reader,
						const FW_SPoint&	position,
						FW_TextAlignment	textAlignment,
						FW_ERenderVerbs		renderVerb,
						FW_HInk				ink,
						FW_HFont			font);
								
FW_Fixed	SL_API	FW_PrivRenderTextBoxString(Environment* ev,
						FW_SGraphicContext& gc,
						FW_HString			string, 
						const FW_SRect&		box,
						FW_TextBoxOptions	options,
						FW_ERenderVerbs		renderVerb,
						FW_HInk				ink,
						FW_HFont			font);

FW_Fixed	SL_API	FW_PrivRenderTextBoxReader(Environment* ev,
						FW_SGraphicContext& gc,
						FW_HTextReader		reader, 
						const FW_SRect&		box,
						FW_TextBoxOptions	options,
						FW_ERenderVerbs		renderVerb,
						FW_HInk				ink,
						FW_HFont			font);

void		SL_API	FW_PrivTextBoxSizeString(Environment* ev,
						FW_SGraphicContext&	gc,
						FW_HString			string, 
						FW_HFont			font,
						FW_TextBoxOptions	options,
						FW_SRect&			textBox);

void		SL_API	FW_PrivTextBoxSizeReader(Environment* ev,
						FW_SGraphicContext& gc,
						FW_HTextReader		reader, 
						FW_HFont			font,
						FW_TextBoxOptions	options,
						FW_SRect&			textBox);

void		SL_API	FW_PrivCalcTextExtentString(Environment* ev,
						FW_SGraphicContext& gc,
						FW_HString			string,
						FW_HFont 			font, 
						FW_SPoint& 			textExtent);

void		SL_API	FW_PrivCalcTextExtentReader(Environment* ev,
						FW_SGraphicContext&	gc,
						FW_HTextReader		reader,
						FW_HFont 			font, 
						FW_SPoint& 			textExtent);

void		SL_API	FW_PrivRenderPicture(Environment* ev,
						FW_SGraphicContext&	gc,
						FW_HPicture			picture,
						const FW_SRect&		dstRect,
						FW_ERenderVerbs		renderVerb);

void		SL_API	FW_PrivRenderBitmap(Environment* ev,
						FW_SGraphicContext&	gc,
						FW_HBitmap			bitmap,
						const FW_SRect&		srcRect,
						const FW_SRect&		dstRect,
						FW_ERenderVerbs		renderVerb,
						FW_HInk				ink);
													
void		SL_API	FW_PrivRenderIcon(Environment* ev,
						FW_SGraphicContext&	gc,
					  	FW_HIcon			icon,
						const FW_SRect&		rect,
						FW_RenderIconTransform	transform,
						FW_RenderIconAlignment	alignment,
						FW_ERenderVerbs		renderVerb);

FW_EXTERN_C_END

// For CFM-68K [sfu]

#if defined(FW_ODFLIB_IMPORT)
#pragma import off
#elif defined(FW_ODFLIB)
#pragma export off
#endif

#endif // SLRENDER_H

